pub struct RoomPreviewDialog {Show 18 fields
go_back_btn: TemplateChild<Button>,
stack: TemplateChild<Stack>,
entry_page: TemplateChild<Box>,
search_entry: TemplateChild<SearchEntry>,
look_up_btn: TemplateChild<LoadingButton>,
room_avatar: TemplateChild<Avatar>,
room_name: TemplateChild<Label>,
room_alias: TemplateChild<Label>,
room_topic: TemplateChild<Label>,
room_members_box: TemplateChild<Box>,
room_members_count: TemplateChild<Label>,
view_or_join_btn: TemplateChild<LoadingButton>,
session: WeakRef<Session>,
uri: RefCell<Option<MatrixRoomIdUri>>,
room: RefCell<Option<RemoteRoom>>,
disable_go_back: Cell<bool>,
room_loading_handler: RefCell<Option<SignalHandlerId>>,
room_list_info_handlers: RefCell<Vec<SignalHandlerId>>,
}Fields
go_back_btn: TemplateChild<Button>stack: TemplateChild<Stack>entry_page: TemplateChild<Box>search_entry: TemplateChild<SearchEntry>look_up_btn: TemplateChild<LoadingButton>room_avatar: TemplateChild<Avatar>room_name: TemplateChild<Label>room_alias: TemplateChild<Label>room_topic: TemplateChild<Label>room_members_box: TemplateChild<Box>room_members_count: TemplateChild<Label>view_or_join_btn: TemplateChild<LoadingButton>session: WeakRef<Session>The current session.
uri: RefCell<Option<MatrixRoomIdUri>>The URI to preview.
room: RefCell<Option<RemoteRoom>>The room that is previewed.
disable_go_back: Cell<bool>Whether the “Go back” button is disabled.
room_loading_handler: RefCell<Option<SignalHandlerId>>room_list_info_handlers: RefCell<Vec<SignalHandlerId>>Implementations
Sourceimpl RoomPreviewDialog
impl RoomPreviewDialog
Sourcefn register_type()
fn register_type()
Registers the type only once.
Sourceimpl RoomPreviewDialog
impl RoomPreviewDialog
Sourcefn set_session(&self, session: Option<&Session>)
fn set_session(&self, session: Option<&Session>)
Set the current session.
Sourcepub(super) fn set_uri(&self, uri: MatrixRoomIdUri)
pub(super) fn set_uri(&self, uri: MatrixRoomIdUri)
Set the room URI to look up.
Sourcepub(super) fn set_room(&self, room: &RemoteRoom)
pub(super) fn set_room(&self, room: &RemoteRoom)
Set the room that is previewed.
Sourcepub(super) fn disable_go_back(&self, disable: bool)
pub(super) fn disable_go_back(&self, disable: bool)
Set whether to disable the “Go back” button.
Sourcefn can_go_back(&self) -> bool
fn can_go_back(&self) -> bool
Whether we can go back to the previous screen.
Sourcefn set_visible_page(&self, page_name: &str)
fn set_visible_page(&self, page_name: &str)
Set the currently visible page.
Sourcefn update_entry_page(&self)
fn update_entry_page(&self)
Update the state of the entry page.
Sourcefn look_up_room(&self)
fn look_up_room(&self)
Look up the room that was entered, if it is valid.
If the room is known, this will open it instead.
fn look_up_room_inner(&self, uri: MatrixRoomIdUri)
Sourcefn fill_details(&self)
fn fill_details(&self)
Fill the details with the given result.
Update the button for viewing or joining the previewed room given the current state.
Sourceasync fn view_or_join_room(&self)
async fn view_or_join_room(&self)
View or join the room that was previewed.
Sourceasync fn knock_or_join_room(&self, room: &RemoteRoom)
async fn knock_or_join_room(&self, room: &RemoteRoom)
Knock or join the room that was previewed, if it is valid.
Sourcefn disconnect_signals(&self)
fn disconnect_signals(&self)
Disconnect the signal handlers of this dialog.